@@ -12,7 +12,7 @@
 ##############################################################################
 """ Views of filesystem directories as folders.
 
-$Id: DirectoryView.py 37369 2005-07-21 17:07:53Z tseaver $
+$Id: DirectoryView.py 40391 2005-11-28 16:21:21Z yuppie $
 """
 
 import re
@@ -32,9 +32,11 @@ from Globals import Persistent
 from OFS.Folder import Folder
 from OFS.ObjectManager import bad_id
 from zLOG import LOG, ERROR
+from zope.interface import implements
 
 from FSMetadata import FSMetadata
 from FSObject import BadFile
+from interfaces import IDirectoryView
 from permissions import AccessContentsInformation
 from permissions import ManagePortal
 from utils import _dtmldir
@@ -47,7 +49,7 @@ def expandpath(p):
     """ utils.expandpath() wrapper for backwards compatibility.
     """
     warn('expandpath() doesn\'t belong to DirectoryView anymore and will be '
-         'removed from that module in CMF 1.6. Please import expandpath from '
+         'removed from that module in CMF 2.0. Please import expandpath from '
          'the utils module.',
          DeprecationWarning)
     return _new_expandpath(p)
@@ -394,11 +396,14 @@ def listFolderHierarchy(ob, path, rval, adding_meta_type=None):
 class DirectoryView (Persistent):
     """ Directory views mount filesystem directories.
     """
+
+    implements(IDirectoryView)
+
     meta_type = 'Filesystem Directory View'
     _dirpath = None
     _objects = ()
 
-    def __init__(self, id, dirpath, fullname=None):
+    def __init__(self, id, dirpath='', fullname=None):
         self.id = id
         self._dirpath = dirpath
 
@@ -418,7 +423,7 @@ class DirectoryView (Persistent):
             if info is not None:
                 # update the directory view with a corrected path
                 self._dirpath = dirpath
-            else:
+            elif self._dirpath:
                 warn('DirectoryView %s refers to a non-existing path %s'
                      % (self.id, dirpath), UserWarning)
         if info is None:
@@ -440,6 +445,8 @@ class DirectoryViewSurrogate (Folder):
     """ Folderish DirectoryView.
     """
 
+    implements(IDirectoryView)
+
     meta_type = 'Filesystem Directory View'
     all_meta_types = ()
     _isDirectoryView = 1
@@ -519,7 +526,7 @@ def createDirectoryView(parent, minimal_fp, id=None):
         else:
             warn('createDirectoryView() expects a slash-separated path '
                  'relative to the Products path. \'%s\' will no longer work '
-                 'in CMF 1.6.' % minimal_fp,
+                 'in CMF 2.0.' % minimal_fp,
                  DeprecationWarning)
         minimal_fp = fixed_minimal_fp
     if not id:
